#ifndef NT2_INCLUDE_FUNCTIONS_PASCAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_PASCAL_HPP_INCLUDED

#include <nt2/gallery/include/functions/pascal.hpp>

#endif
